(releasenotes)=

# Release Notes

Specific release notes will be included here, as additional features are implemented. Some planned additions are listed below. If something in particular is desired, please make a [feature request](https://github.com/smolgp-dev/smolgp/issues).

- Sampling procedure using the state space definition.

- Nonzero mean functions (see [Fittng a Mean Function](https://tinygp.readthedocs.io/en/latest/tutorials/means.html)).

- More expressive noise models (see [tinygp.noise](https://tinygp.readthedocs.io/en/latest/api/noise.html)).

- Tutorials for building models with multivariate inputs/outputs, and spatiotemporal GPs.

- Full conditioned covariance matrix as a product of the GP object

- Predictions at arbitrary times _with_ arbitrary exposure times